@@ -12,19 +12,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import os
+import uuid
 from json import JSONDecodeError
 
 import sentry_sdk
 from asgi_correlation_id import CorrelationIdMiddleware
 from fastapi import FastAPI
+from fastapi.responses import ORJSONResponse
 from opentelemetry.exporter.otlp.proto.grpc.metric_exporter import OTLPMetricExporter
 from opentelemetry.exporter.otlp.proto.grpc.trace_exporter import OTLPSpanExporter
 from opentelemetry.sdk.metrics import MeterProvider
 from opentelemetry.sdk.metrics.export import PeriodicExportingMetricReader
 from opentelemetry.sdk.trace import TracerProvider
-from opentelemetry.sdk.trace.export import (
-    BatchSpanProcessor,
-)
+from opentelemetry.sdk.trace.export import BatchSpanProcessor
 from opentelemetry.sdk.trace.sampling import TraceIdRatioBased
 
 from superlinked.framework.common.exception import (
@@ -48,7 +49,7 @@ from superlinked.server.exception.exception_handler import (
     handle_unprocessable_entity,
 )
 from superlinked.server.middleware.lifespan_event import lifespan
-from superlinked.server.middleware.timing_middleware import add_timing_middleware
+from superlinked.server.middleware.timing_middleware import AccessTimingASGIMiddleware
 from superlinked.server.router.management_router import router as management_router
 from superlinked.server.util.superlinked_app_downloader_util import download_from_gcs
 
@@ -78,12 +79,12 @@ class ServerApp:
                 settings.BUCKET_NAME, settings.BUCKET_PREFIX, settings.APP_MODULE_PATH, settings.PROJECT_ID
             )
         self._init_sentry()
-        app = FastAPI(lifespan=lifespan)
+        app = FastAPI(lifespan=lifespan, default_response_class=ORJSONResponse)
         self._init_opentelemetry()
         self._setup_exception_handler(app)
         app.include_router(management_router)
 
-        add_timing_middleware(app, debug_endpoints=["/health", "/version"])
+        app.add_middleware(AccessTimingASGIMiddleware)
         app.add_middleware(CorrelationIdMiddleware)  # This must be the last middleware
 
         register_dependencies()
@@ -105,6 +106,8 @@ class ServerApp:
 
         server_version = VersionResolver.get_version_for_package("superlinked-server") or "unknown"
         labels = {
+            "service.instance.id": str(uuid.uuid4()),
+            "service.instance.pid": str(os.getpid()),
             "service.name": settings.OPENTELEMETRY_COMPONENT_NAME,
             "service.version": server_version,
             "environment": settings.ENVIRONMENT_NAME,
@@ -125,7 +128,9 @@ class ServerApp:
         )
 
         metric_exporter = OTLPMetricExporter(endpoint=settings.OPENTELEMETRY_COLLECTOR_ENDPOINT, insecure=True)
-        metric_reader = PeriodicExportingMetricReader(exporter=metric_exporter)
+        metric_reader = PeriodicExportingMetricReader(
+            exporter=metric_exporter, export_interval_millis=settings.OPENTELEMETRY_METRICS_EXPORT_INTERVAL_MS
+        )
 
         trace_exporter = OTLPSpanExporter(
             endpoint=settings.OPENTELEMETRY_COLLECTOR_ENDPOINT,
