@@ -18,14 +18,13 @@ import secrets
 from fastapi import HTTPException, Security, status
 from fastapi.security import APIKeyHeader
 
-from superlinked.server.configuration.settings import Settings
+from superlinked.server.configuration.settings import settings
 
 API_KEY_NAME = "Authorization"  # pragma: allowlist secret
 api_key_header = APIKeyHeader(name=API_KEY_NAME, auto_error=False)
 
 
 async def verify_api_key(api_key: str = Security(api_key_header)) -> None:
-    settings = Settings()
     api_key = api_key or ""  # compare_digest does not accept None
     if settings.API_KEY and not secrets.compare_digest(api_key, settings.API_KEY):
         raise HTTPException(
