@@ -17,7 +17,7 @@ from datetime import datetime
 
 import inject
 from fastapi import APIRouter, Depends
-from fastapi.responses import JSONResponse
+from fastapi.responses import JSONResponse, RedirectResponse
 from fastapi_restful.cbv import cbv
 from starlette import status
 
@@ -33,6 +33,15 @@ router = APIRouter()
 class ManagementRouter:
     __data_loader: DataLoader = Depends(lambda: inject.instance(DataLoader))
 
+    @router.get(
+        "/",
+        summary="Redirects to the API documentation",
+        status_code=status.HTTP_307_TEMPORARY_REDIRECT,
+        include_in_schema=False,
+    )
+    async def redirect_to_docs(self) -> RedirectResponse:
+        return RedirectResponse(url="/docs", status_code=status.HTTP_307_TEMPORARY_REDIRECT)
+
     @router.get(
         "/health",
         summary="Returns with 200 OK, if the application is healthy",
