@@ -12,6 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+
+import orjson
 import structlog
 from beartype.typing import Any
 from fastapi import Request, Response, status
@@ -41,14 +43,14 @@ class FastApiHandler:
         self.__rest_handler = rest_handler
 
     async def ingest(self, request: Request) -> Response:
-        payload = await request.json()
+        payload = await self.__json_loads(request)
         with telemetry.span("api_handler.ingest", attributes={"path": request.url.path}):
             await self.__rest_handler._ingest_handler(payload, request.url.path)
         logger.debug("ingested data", path=request.url.path, pii_payload=payload)
         return Response(status_code=status.HTTP_202_ACCEPTED)
 
     async def query(self, request: Request) -> Response:
-        payload = await request.json()
+        payload = await self.__json_loads(request)
         query_user_config = self.calculate_query_user_config(request)
         labels: dict[str, TelemetryAttributeType] = {
             "path": request.url.path,
@@ -101,3 +103,6 @@ class FastApiHandler:
             return int(batch_size_str)
         except ValueError as e:
             raise ValueError(f"Invalid batch size: {batch_size_str}. Must be an integer.") from e
+
+    async def __json_loads(self, request: Request) -> dict:
+        return orjson.loads(await request.body())  # pylint: disable=no-member  # It exists
